# ortfodb

A [ortfodb](https://github.com/ortfo/db) client library for Python.

Generated from [ortfo's JSON schemas](https://github.com/ortfo/db/tree/main/schemas) thanks to [Quicktype](https://quicktype.io)
